==> jc-1.4.0.tar.gz: soot/util/NumberedString.h <==
// public final class soot.util.NumberedString

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ee92c5731980adf3 soot_util_NumberedString

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_NumberedString_H_
#define _JC_soot_util_NumberedString_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_util_NumberedString$sub_refs	_jc_soot_util_NumberedString$sub_refs;
typedef struct _jc_soot_util_NumberedString$sub_nonrefs	_jc_soot_util_NumberedString$sub_nonrefs;
typedef struct _jc_soot_util_NumberedString$refs	_jc_soot_util_NumberedString$refs;
typedef struct _jc_soot_util_NumberedString$nonrefs	_jc_soot_util_NumberedString$nonrefs;
typedef struct _jc_soot_util_NumberedString$object	_jc_soot_util_NumberedString$object;

typedef const struct _jc_soot_util_NumberedString$vmethods	_jc_soot_util_NumberedString$vmethods;
typedef const struct _jc_soot_util_NumberedString$vtable	_jc_soot_util_NumberedString$vtable;
typedef const struct _jc_soot_util_NumberedString$vtype	_jc_soot_util_NumberedString$vtype;

// Constructors
extern void _jc_soot_util_NumberedString$method$_init$c31b894660454d13(_jc_env *, struct _jc_soot_util_NumberedString$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern jint _jc_soot_util_NumberedString$method$getNumber$9f4729baae2d2787(_jc_env *, struct _jc_soot_util_NumberedString$object *);
extern struct _jc_java_lang_String$object *_jc_soot_util_NumberedString$method$getString$fb8e0f9b9b45f51c(_jc_env *, struct _jc_soot_util_NumberedString$object *);
extern void _jc_soot_util_NumberedString$method$setNumber$72e40df050255abc(_jc_env *, struct _jc_soot_util_NumberedString$object *, jint);
extern struct _jc_java_lang_String$object *_jc_soot_util_NumberedString$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_util_NumberedString$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_util_NumberedString$method_info$getNumber$9f4729baae2d2787;
extern _jc_method _jc_soot_util_NumberedString$method_info$getString$fb8e0f9b9b45f51c;
extern _jc_method _jc_soot_util_NumberedString$method_info$setNumber$72e40df050255abc;
extern _jc_method _jc_soot_util_NumberedString$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_util_NumberedString$vmethods {
	jint	(*getNumber$9f4729baae2d2787)(_jc_env *, struct _jc_soot_util_NumberedString$object *);
	struct _jc_java_lang_String$object	*(*getString$fb8e0f9b9b45f51c)(_jc_env *, struct _jc_soot_util_NumberedString$object *);
	void	(*setNumber$72e40df050255abc)(_jc_env *, struct _jc_soot_util_NumberedString$object *, jint);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_util_NumberedString$object *);
};

// Vtable
struct _jc_soot_util_NumberedString$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_NumberedString$vmethods	soot_util_NumberedString;
};

// Vtype
struct _jc_soot_util_NumberedString$vtype {
	_jc_type			type;
	_jc_soot_util_NumberedString$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_NumberedString$sub_refs {
	struct _jc_java_lang_String$object	*s;
};

// Reference instance fields (object)
struct _jc_soot_util_NumberedString$refs {
    _jc_soot_util_NumberedString$sub_refs	soot_util_NumberedString;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_NumberedString$sub_nonrefs {
	jint	number;
};

// Non-reference instance fields (object)
struct _jc_soot_util_NumberedString$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_NumberedString$sub_nonrefs	soot_util_NumberedString;
};

// Object instance structure
struct _jc_soot_util_NumberedString$object {
	_jc_soot_util_NumberedString$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_NumberedString$vtype	*vtype;
	_jc_soot_util_NumberedString$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_NumberedString$vtype _jc_soot_util_NumberedString$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_NumberedString, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_NumberedString$class_object;

#endif	/* _JC_soot_util_NumberedString_H_ */

==> jc-1.4.6.tar.gz: soot/util/NumberedString.h <==
// public final class soot.util.NumberedString

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ee92c5731980adf3 soot_util_NumberedString

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_NumberedString_H_
#define _JC_soot_util_NumberedString_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_util_NumberedString$sub_refs	_jc_soot_util_NumberedString$sub_refs;
typedef struct _jc_soot_util_NumberedString$sub_nonrefs	_jc_soot_util_NumberedString$sub_nonrefs;
typedef struct _jc_soot_util_NumberedString$refs	_jc_soot_util_NumberedString$refs;
typedef struct _jc_soot_util_NumberedString$nonrefs	_jc_soot_util_NumberedString$nonrefs;
typedef struct _jc_soot_util_NumberedString$object	_jc_soot_util_NumberedString$object;

typedef const struct _jc_soot_util_NumberedString$vmethods	_jc_soot_util_NumberedString$vmethods;
typedef const struct _jc_soot_util_NumberedString$vtable	_jc_soot_util_NumberedString$vtable;
typedef const struct _jc_soot_util_NumberedString$vtype	_jc_soot_util_NumberedString$vtype;

// Constructors
extern void _jc_soot_util_NumberedString$method$_init$c31b894660454d13(_jc_env *, struct _jc_soot_util_NumberedString$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_soot_util_NumberedString$method$getNumber$9f4729baae2d2787(_jc_env *, struct _jc_soot_util_NumberedString$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_util_NumberedString$method$getString$fb8e0f9b9b45f51c(_jc_env *, struct _jc_soot_util_NumberedString$object *) _JC_JCNI_ATTR;
extern void _jc_soot_util_NumberedString$method$setNumber$72e40df050255abc(_jc_env *, struct _jc_soot_util_NumberedString$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_util_NumberedString$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_util_NumberedString$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_util_NumberedString$method_info$getNumber$9f4729baae2d2787;
extern _jc_method _jc_soot_util_NumberedString$method_info$getString$fb8e0f9b9b45f51c;
extern _jc_method _jc_soot_util_NumberedString$method_info$setNumber$72e40df050255abc;
extern _jc_method _jc_soot_util_NumberedString$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_util_NumberedString$vmethods {
	jint	(*getNumber$9f4729baae2d2787)(_jc_env *, struct _jc_soot_util_NumberedString$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getString$fb8e0f9b9b45f51c)(_jc_env *, struct _jc_soot_util_NumberedString$object *) _JC_JCNI_ATTR;
	void	(*setNumber$72e40df050255abc)(_jc_env *, struct _jc_soot_util_NumberedString$object *, jint) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_util_NumberedString$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_util_NumberedString$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_NumberedString$vmethods	soot_util_NumberedString;
};

// Vtype
struct _jc_soot_util_NumberedString$vtype {
	_jc_type			type;
	_jc_soot_util_NumberedString$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_NumberedString$sub_refs {
	struct _jc_java_lang_String$object	*s;
};

// Reference instance fields (object)
struct _jc_soot_util_NumberedString$refs {
    _jc_soot_util_NumberedString$sub_refs	soot_util_NumberedString;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_NumberedString$sub_nonrefs {
	jint	number;
};

// Non-reference instance fields (object)
struct _jc_soot_util_NumberedString$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_NumberedString$sub_nonrefs	soot_util_NumberedString;
};

// Object instance structure
struct _jc_soot_util_NumberedString$object {
	_jc_soot_util_NumberedString$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_NumberedString$vtype	*vtype;
	_jc_soot_util_NumberedString$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_NumberedString$vtype _jc_soot_util_NumberedString$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_NumberedString, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_NumberedString$class_object;

#endif	/* _JC_soot_util_NumberedString_H_ */
